Module: Google::Cloud::Recommender

Defined in:
lib/google/cloud/recommender.rb,
lib/google/cloud/recommender/version.rb

Constant Summary collapse

VERSION =
"0.2.0".freeze

Class Method Summary collapse

Class Method Details

.configure {|Google::Cloud.configure.recommender| ... } ⇒ Google::Cloud::Config

Configure the google-cloud-recommender library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Integer) - Default timeout in milliseconds.
  • metadata (type: Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds.
    * `:max_delay` (*type:* `Numeric`) - The max delay in seconds.
    * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier.
    * `:retry_codes` (*type:* `Array<String>`) -
    The error codes that should trigger a retry.

Yields:

Returns:

  • (Google::Cloud::Config) —

    The default configuration used by this library



100
101
102
103
104
# File 'lib/google/cloud/recommender.rb', line 100

def self.configure
  yield Google::Cloud.configure.recommender if block_given?

  Google::Cloud.configure.recommender
end

.recommender_service(version: :v1, &block) ⇒ Recommender::Client

Create a new client object for Recommender.

By default, this returns an instance of Google::Cloud::Recommender::V1::Recommender::Client for version V1 of the API. However, you can specify specify a different API version by passing it in the version parameter. If the Recommender service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned.

About Recommender

Provides recommendations for cloud customers for various categories like performance optimization, cost savings, reliability, feature discovery, etc. These recommendations are generated automatically based on analysis of user resources, configuration and monitoring metrics.

Parameters:

  • version (String, Symbol) (defaults to: :v1) —

    The API version to connect to. Optional. Defaults to :v1.

Returns:

  • (Recommender::Client) —

    A client object for the specified version.



61
62
63
64
65
66
67
68
69
70
# File 'lib/google/cloud/recommender.rb', line 61

def self.recommender_service version: :v1, &block
  require "google/cloud/recommender/#{version.to_s.downcase}"

  package_name = Google::Cloud::Recommender
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  package_module = Google::Cloud::Recommender.const_get package_name
  package_module.const_get(:Recommender).const_get(:Client).new(&block)
end